##  [](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/edge_update_schedules/operation/RemoteUpdatesAgentVersions)Fetches the supported versions of the agent to update/rollback
**Access policy** : authenticated
##### Authorizations:
_ApiKeyAuth_ _jwt_
### Responses
**200**
OK
**400**
Invalid request
**500**
Server error
get/edge_update_schedules/agent_versions
https://api-docs.portainer.io/api/edge_update_schedules/agent_versions
###  Response samples
  * 200


Content type
application/json
Copy
`[
  * "string"

 ]`
